@@ -11,12 +11,11 @@ CERTFILE=$SSLDIR/dovecotcert.pem
 KEYFILE=$SSLDIR/private/dovecot.pem
 
 #if [ ! -d $SSLDIR/certs ]; then
-#  echo $SSLDIR/certs directory doesn't exist
+#  echo "$SSLDIR/certs directory doesn't exist"
 #fi
 
 if [ ! -d $SSLDIR/private ]; then
   echo "$SSLDIR/private directory doesn't exist"
-  exit 1
 fi
 
 if [ -f $CERTFILE ]; then
